==> ejc-credentials-impl-3.0.0-20220608.025626-40-sources.jar: com/ejianc/certify/bean/CertifyTransferEntity.java <==
package com.ejianc.certify.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 证照调动单
 * 
 * @author generator
 * 
 */
 @TableName("jzctm_certiftransfer")
public class CertifyTransferEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pk_certifreg")
    private Long pkCertifreg; // 证照登记单主键
    @TableField(value="pk_group")
    private String pkGroup; // 集团
    @TableField(value="pk_org")
    private Long pkOrg; // 原管理组织
    @TableField(value="pk_managedept")
    private Long pkManagedept; // 原管理部门
    @TableField(value="pk_drorg")
    private Long pkDrorg; // 调入管理组织
    @TableField(value="pk_drdept")
    private Long pkDrdept; // 调入管理部门
    @TableField(value="dbilldate")
    private String dbilldate; // 单据日期
    @TableField(value="vbillcode")
    private String vbillcode; // 单据编码
    @TableField(value="pk_certiftype")
    private Long pkCertiftype; // 证照名称（选择证照登记单带出）
    @TableField(value="certifcode")
    private String certifcode; // 证书编号（选择证照登记单带出）
    @TableField(value="zj_code")
    private String zjCode; // 证件编码（选择证照登记单带出）
    @TableField(value="pk_certpsn")
    private Long pkCertpsn; // 持证人员
    @TableField(value="card_id")
    private String cardId; // 身份证号码
    @TableField(value="psn_phone")
    private String psnPhone; // 电话号码
    @TableField(value="cert_status")
    private Integer certStatus; // 证照状态（0-未生效 1-生效 2-失效）
    @TableField(value="pk_billtype")
    private String pkBilltype; // 单据类型
    @TableField(value="vmemo")
    private String vmemo; // 备注
    @TableField(value="vbusitype")
    private String vbusitype; // 业务类型
    @TableField(value="applyer")
    private Long applyer; // 调出发起人
    @TableField(value="applyerorg")
    private Long applyerorg; // 调出发起人组织
    @TableField(value="approver")
    private String approver; // 审批人
    @TableField(value="taudittime")
    private String taudittime; // 审批时间
    @TableField(value="vapprovenote")
    private String vapprovenote; // 审批附言
    @TableField(value="vdef1")
    private String vdef1; // 
    @TableField(value="vdef10")
    private String vdef10; // 
    @TableField(value="vdef2")
    private String vdef2; // 
    @TableField(value="vdef3")
    private String vdef3; // 
    @TableField(value="vdef4")
    private String vdef4; // 
    @TableField(value="vdef5")
    private String vdef5; // 
    @TableField(value="vdef6")
    private String vdef6; // 
    @TableField(value="vdef7")
    private String vdef7; // 
    @TableField(value="vdef8")
    private String vdef8; // 
    @TableField(value="vdef9")
    private String vdef9; // 
    @TableField(value="yj_isrecevie")
    private String yjIsrecevie; // 调入组织是否收到原件
    @TableField(value="ts")
    private Date ts; // 时间戳
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    
    
    

    public Long getPkCertifreg() {
        return pkCertifreg;
    }

    public void setPkCertifreg(Long pkCertifreg) {
        this.pkCertifreg = pkCertifreg;
    }
    public String getPkGroup() {
        return pkGroup;
    }

    public void setPkGroup(String pkGroup) {
        this.pkGroup = pkGroup;
    }
    public Long getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }
    public Long getPkManagedept() {
        return pkManagedept;
    }

    public void setPkManagedept(Long pkManagedept) {
        this.pkManagedept = pkManagedept;
    }
    public Long getPkDrorg() {
        return pkDrorg;
    }

    public void setPkDrorg(Long pkDrorg) {
        this.pkDrorg = pkDrorg;
    }
    public Long getPkDrdept() {
        return pkDrdept;
    }

    public void setPkDrdept(Long pkDrdept) {
        this.pkDrdept = pkDrdept;
    }
    public String getDbilldate() {
        return dbilldate;
    }

    public void setDbilldate(String dbilldate) {
        this.dbilldate = dbilldate;
    }
    public String getVbillcode() {
        return vbillcode;
    }

    public void setVbillcode(String vbillcode) {
        this.vbillcode = vbillcode;
    }
    public Long getPkCertiftype() {
        return pkCertiftype;
    }

    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }
    public String getCertifcode() {
        return certifcode;
    }

    public void setCertifcode(String certifcode) {
        this.certifcode = certifcode;
    }
    public String getZjCode() {
        return zjCode;
    }

    public void setZjCode(String zjCode) {
        this.zjCode = zjCode;
    }
    public Long getPkCertpsn() {
        return pkCertpsn;
    }

    public void setPkCertpsn(Long pkCertpsn) {
        this.pkCertpsn = pkCertpsn;
    }
    public String getCardId() {
        return cardId;
    }

    public void setCardId(String cardId) {
        this.cardId = cardId;
    }
    public String getPsnPhone() {
        return psnPhone;
    }

    public void setPsnPhone(String psnPhone) {
        this.psnPhone = psnPhone;
    }
    public Integer getCertStatus() {
        return certStatus;
    }

    public void setCertStatus(Integer certStatus) {
        this.certStatus = certStatus;
    }
    public String getPkBilltype() {
        return pkBilltype;
    }

    public void setPkBilltype(String pkBilltype) {
        this.pkBilltype = pkBilltype;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public String getVbusitype() {
        return vbusitype;
    }

    public void setVbusitype(String vbusitype) {
        this.vbusitype = vbusitype;
    }
    public Long getApplyer() {
        return applyer;
    }

    public void setApplyer(Long applyer) {
        this.applyer = applyer;
    }
    public Long getApplyerorg() {
        return applyerorg;
    }

    public void setApplyerorg(Long applyerorg) {
        this.applyerorg = applyerorg;
    }
    public String getApprover() {
        return approver;
    }

    public void setApprover(String approver) {
        this.approver = approver;
    }
    public String getTaudittime() {
        return taudittime;
    }

    public void setTaudittime(String taudittime) {
        this.taudittime = taudittime;
    }
    public String getVapprovenote() {
        return vapprovenote;
    }

    public void setVapprovenote(String vapprovenote) {
        this.vapprovenote = vapprovenote;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    public String getYjIsrecevie() {
        return yjIsrecevie;
    }

    public void setYjIsrecevie(String yjIsrecevie) {
        this.yjIsrecevie = yjIsrecevie;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
}

==> ejc-credentials-impl-3.0.0-20220614.031901-51-sources.jar: com/ejianc/certify/bean/CertifyTransferEntity.java <==
package com.ejianc.certify.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 证照调动单
 *
 * @author generator
 */
@TableName("jzctm_certiftransfer")
public class CertifyTransferEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    @TableField(value = "name")
    private String name; // 调动单名称
    @TableField(value = "pk_certifreg")
    private Long pkCertifreg; // 证照登记单主键
    @TableField(value = "pk_group")
    private String pkGroup; // 集团
    @TableField(value = "pk_org")
    private Long pkOrg; // 原管理组织
    @TableField(value = "pk_managedept")
    private Long pkManagedept; // 原管理部门
    @TableField(value = "pk_drorg")
    private Long pkDrorg; // 调入管理组织
    @TableField(value = "pk_drdept")
    private Long pkDrdept; // 调入管理部门
    @TableField(value = "dbilldate")
    private String dbilldate; // 单据日期
    @TableField(value = "vbillcode")
    private String vbillcode; // 单据编码
    @TableField(value = "pk_certiftype")
    private Long pkCertiftype; // 证照名称（选择证照登记单带出）
    @TableField(value = "certifcode")
    private String certifcode; // 证书编号（选择证照登记单带出）
    @TableField(value = "zj_code")
    private String zjCode; // 证件编码（选择证照登记单带出）
    @TableField(value = "pk_certpsn")
    private Long pkCertpsn; // 持证人员
    @TableField(value = "card_id")
    private String cardId; // 身份证号码
    @TableField(value = "psn_phone")
    private String psnPhone; // 电话号码
    @TableField(value = "cert_status")
    private Integer certStatus; // 证照状态（0-未生效 1-生效 2-失效）
    @TableField(value = "pk_billtype")
    private String pkBilltype; // 单据类型
    @TableField(value = "vmemo")
    private String vmemo; // 备注
    @TableField(value = "vbusitype")
    private String vbusitype; // 业务类型
    @TableField(value = "applyer")
    private Long applyer; // 调出发起人
    @TableField(value = "applyerorg")
    private Long applyerorg; // 调出发起人组织
    @TableField(value = "approver")
    private String approver; // 审批人
    @TableField(value = "taudittime")
    private String taudittime; // 审批时间
    @TableField(value = "vapprovenote")
    private String vapprovenote; // 审批附言
    @TableField(value = "vdef1")
    private String vdef1; // 
    @TableField(value = "vdef10")
    private String vdef10; // 
    @TableField(value = "vdef2")
    private String vdef2; // 
    @TableField(value = "vdef3")
    private String vdef3; // 
    @TableField(value = "vdef4")
    private String vdef4; // 
    @TableField(value = "vdef5")
    private String vdef5; // 
    @TableField(value = "vdef6")
    private String vdef6; // 
    @TableField(value = "vdef7")
    private String vdef7; // 
    @TableField(value = "vdef8")
    private String vdef8; // 
    @TableField(value = "vdef9")
    private String vdef9; // 
    @TableField(value = "yj_isrecevie")
    private String yjIsrecevie; // 调入组织是否收到原件
    @TableField(value = "ts")
    private Date ts; // 时间戳
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态


    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getPkCertifreg() {
        return pkCertifreg;
    }

    public void setPkCertifreg(Long pkCertifreg) {
        this.pkCertifreg = pkCertifreg;
    }

    public String getPkGroup() {
        return pkGroup;
    }

    public void setPkGroup(String pkGroup) {
        this.pkGroup = pkGroup;
    }

    public Long getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }

    public Long getPkManagedept() {
        return pkManagedept;
    }

    public void setPkManagedept(Long pkManagedept) {
        this.pkManagedept = pkManagedept;
    }

    public Long getPkDrorg() {
        return pkDrorg;
    }

    public void setPkDrorg(Long pkDrorg) {
        this.pkDrorg = pkDrorg;
    }

    public Long getPkDrdept() {
        return pkDrdept;
    }

    public void setPkDrdept(Long pkDrdept) {
        this.pkDrdept = pkDrdept;
    }

    public String getDbilldate() {
        return dbilldate;
    }

    public void setDbilldate(String dbilldate) {
        this.dbilldate = dbilldate;
    }

    public String getVbillcode() {
        return vbillcode;
    }

    public void setVbillcode(String vbillcode) {
        this.vbillcode = vbillcode;
    }

    public Long getPkCertiftype() {
        return pkCertiftype;
    }

    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }

    public String getCertifcode() {
        return certifcode;
    }

    public void setCertifcode(String certifcode) {
        this.certifcode = certifcode;
    }

    public String getZjCode() {
        return zjCode;
    }

    public void setZjCode(String zjCode) {
        this.zjCode = zjCode;
    }

    public Long getPkCertpsn() {
        return pkCertpsn;
    }

    public void setPkCertpsn(Long pkCertpsn) {
        this.pkCertpsn = pkCertpsn;
    }

    public String getCardId() {
        return cardId;
    }

    public void setCardId(String cardId) {
        this.cardId = cardId;
    }

    public String getPsnPhone() {
        return psnPhone;
    }

    public void setPsnPhone(String psnPhone) {
        this.psnPhone = psnPhone;
    }

    public Integer getCertStatus() {
        return certStatus;
    }

    public void setCertStatus(Integer certStatus) {
        this.certStatus = certStatus;
    }

    public String getPkBilltype() {
        return pkBilltype;
    }

    public void setPkBilltype(String pkBilltype) {
        this.pkBilltype = pkBilltype;
    }

    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }

    public String getVbusitype() {
        return vbusitype;
    }

    public void setVbusitype(String vbusitype) {
        this.vbusitype = vbusitype;
    }

    public Long getApplyer() {
        return applyer;
    }

    public void setApplyer(Long applyer) {
        this.applyer = applyer;
    }

    public Long getApplyerorg() {
        return applyerorg;
    }

    public void setApplyerorg(Long applyerorg) {
        this.applyerorg = applyerorg;
    }

    public String getApprover() {
        return approver;
    }

    public void setApprover(String approver) {
        this.approver = approver;
    }

    public String getTaudittime() {
        return taudittime;
    }

    public void setTaudittime(String taudittime) {
        this.taudittime = taudittime;
    }

    public String getVapprovenote() {
        return vapprovenote;
    }

    public void setVapprovenote(String vapprovenote) {
        this.vapprovenote = vapprovenote;
    }

    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }

    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }

    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }

    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }

    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }

    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }

    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }

    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }

    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }

    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }

    public String getYjIsrecevie() {
        return yjIsrecevie;
    }

    public void setYjIsrecevie(String yjIsrecevie) {
        this.yjIsrecevie = yjIsrecevie;
    }

    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

}
